summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--LibertyComment.php4
-rw-r--r--LibertyContent.php14
-rw-r--r--attachment_browser.php6
-rw-r--r--liberty_rss.php6
-rw-r--r--list_content.php8
-rw-r--r--plugins/data.category.php12
6 files changed, 25 insertions, 25 deletions
diff --git a/LibertyComment.php b/LibertyComment.php
index 144dbc1..85cf23e 100644
--- a/LibertyComment.php
+++ b/LibertyComment.php
@@ -3,7 +3,7 @@
* Management of Liberty Content
*
* @package liberty
- * @version $Header: /cvsroot/bitweaver/_bit_liberty/LibertyComment.php,v 1.10 2006/02/02 07:55:24 squareing Exp $
+ * @version $Header: /cvsroot/bitweaver/_bit_liberty/LibertyComment.php,v 1.11 2006/02/06 00:09:01 squareing Exp $
* @author spider <spider@steelsun.com>
*/
@@ -158,7 +158,7 @@ class LibertyComment extends LibertyContent {
$pParamHash['sort_mode'] = 'last_modified_desc';
}
if( empty( $pParamHash['max_records'] ) ) {
- $pParamHash['max_records'] = $gBitSystem->getPreference( 'maxRecords' );
+ $pParamHash['max_records'] = $gBitSystem->getPreference( 'max_records' );
}
LibertyContent::prepGetList( $pParamHash );
$sort_mode = $this->mDb->convert_sortmode($pParamHash['sort_mode']);
diff --git a/attachment_browser.php b/attachment_browser.php
index daab591..00f94a1 100644
--- a/attachment_browser.php
+++ b/attachment_browser.php
@@ -3,7 +3,7 @@
* attachment_browser
*
* @author spider <spider@steelsun.com>
- * @version $Revision: 1.7 $
+ * @version $Revision: 1.8 $
* @package liberty
* @subpackage functions
*/
@@ -24,9 +24,9 @@ $gBitSmarty->assign( 'userAttachments', $userAttachments );
// pagination
$offset = @BitBase::verifyId( $_REQUEST['offset'] ) ? $_REQUEST['offset'] : 0;
$gBitSmarty->assign( 'curPage', $pgnPage = @BitBase::verifyId( $_REQUEST['pgnPage'] ) ? $_REQUEST['pgnPage'] : 1 );
-$offset = ( $pgnPage - 1 ) * $gBitSystem->mPrefs['maxRecords'];
+$offset = ( $pgnPage - 1 ) * $gBitSystem->mPrefs['max_records'];
// calculate page number
-$numPages = ceil( $userAttachments['cant'] / $gBitSystem->mPrefs['maxRecords'] );
+$numPages = ceil( $userAttachments['cant'] / $gBitSystem->mPrefs['max_records'] );
$gBitSmarty->assign( 'numPages', $numPages );
?>
diff --git a/liberty_rss.php b/liberty_rss.php
index 063b6ef..aa8d6b7 100644
--- a/liberty_rss.php
+++ b/liberty_rss.php
@@ -1,6 +1,6 @@
<?php
/**
- * @version $Header: /cvsroot/bitweaver/_bit_liberty/liberty_rss.php,v 1.1 2006/01/29 13:16:31 squareing Exp $
+ * @version $Header: /cvsroot/bitweaver/_bit_liberty/liberty_rss.php,v 1.2 2006/02/06 00:09:01 squareing Exp $
* @package wiki
* @subpackage functions
*/
@@ -14,8 +14,8 @@ require_once( LIBERTY_PKG_PATH."LibertyContent.php" );
$gBitSystem->verifyPackage( 'rss' );
-$rss->title = $gBitSystem->getPreference( 'title_rss_liberty', $gBitSystem->mPrefs['siteTitle'].' - '.tra( 'Liberty' ) );
-$rss->description = $gBitSystem->getPreference( 'desc_rss_liberty', $gBitSystem->mPrefs['siteTitle'].' - '.tra( 'RSS Feed' ) );
+$rss->title = $gBitSystem->getPreference( 'title_rss_liberty', $gBitSystem->mPrefs['site_title'].' - '.tra( 'Liberty' ) );
+$rss->description = $gBitSystem->getPreference( 'desc_rss_liberty', $gBitSystem->mPrefs['site_title'].' - '.tra( 'RSS Feed' ) );
// check permission to view liberty pages
if( !$gBitUser->hasPermission( 'bit_p_view' ) ) {
diff --git a/list_content.php b/list_content.php
index 420f233..b50b257 100644
--- a/list_content.php
+++ b/list_content.php
@@ -3,7 +3,7 @@
* list_content
*
* @author spider <spider@steelsun.com>
- * @version $Revision: 1.8 $
+ * @version $Revision: 1.9 $
* @package liberty
* @subpackage functions
*/
@@ -19,17 +19,17 @@ if( !empty( $_REQUEST['sort_mode'] ) ) {
$gBitSmarty->assign( 'sort_mode', $content_sort_mode );
}
-$max_content = $gBitSystem->mPrefs['maxRecords'];
+$max_content = $gBitSystem->mPrefs['max_records'];
$offset_content = @BitBase::verifyId( $_REQUEST['offset'] ) ? $_REQUEST['offset'] : 0;
$gBitSmarty->assign( 'user_id', @BitBase::verifyId( $_REQUEST['user_id'] ) ? $_REQUEST['user_id'] : NULL );
$gBitSmarty->assign( 'curPage', $page = @BitBase::verifyId( $_REQUEST['page'] ) ? $_REQUEST['page'] : 1 );
-$offset_content = ( $page - 1 ) * $gBitSystem->mPrefs['maxRecords'];
+$offset_content = ( $page - 1 ) * $gBitSystem->mPrefs['max_records'];
// now that we have all the offsets, we can get the content list
include_once( LIBERTY_PKG_PATH.'get_content_list_inc.php' );
// calculate page number
-$numPages = ceil( $contentList['cant'] / $gBitSystem->mPrefs['maxRecords'] );
+$numPages = ceil( $contentList['cant'] / $gBitSystem->mPrefs['max_records'] );
$gBitSmarty->assign( 'numPages', $numPages );
//$gBitSmarty->assign_by_ref('offset', $offset);
diff --git a/LibertyContent.php b/LibertyContent.php
index c03f0f8..1c1f84e 100644
--- a/LibertyContent.php
+++ b/LibertyContent.php
@@ -3,7 +3,7 @@
* Management of Liberty content
*
* @package liberty
-* @version $Header: /cvsroot/bitweaver/_bit_liberty/LibertyContent.php,v 1.39 2006/02/04 10:10:51 squareing Exp $
+* @version $Header: /cvsroot/bitweaver/_bit_liberty/LibertyContent.php,v 1.40 2006/02/06 00:09:01 squareing Exp $
* @author spider <spider@steelsun.com>
*/
@@ -982,7 +982,7 @@ class LibertyContent extends LibertyBase {
'backlinks_desc'
))) {
$old_offset = $pListHash['offset'];
- $old_maxRecords = $pListHash['max_records'];
+ $old_max_records = $pListHash['max_records'];
$old_sort_mode = $pListHash['sort_mode'];
$pListHash['sort_mode'] = 'modifier_user_desc';
$pListHash['offset'] = 0;
@@ -1062,9 +1062,9 @@ class LibertyContent extends LibertyBase {
}
- // If sort mode is versions then offset is 0, maxRecords is -1 (again) and sort_mode is nil
- // If sort mode is links then offset is 0, maxRecords is -1 (again) and sort_mode is nil
- // If sort mode is backlinks then offset is 0, maxRecords is -1 (again) and sort_mode is nil
+ // If sort mode is versions then offset is 0, max_records is -1 (again) and sort_mode is nil
+ // If sort mode is links then offset is 0, max_records is -1 (again) and sort_mode is nil
+ // If sort mode is backlinks then offset is 0, max_records is -1 (again) and sort_mode is nil
$query = "
SELECT
uue.`login` AS `modifier_user`,
@@ -1118,7 +1118,7 @@ class LibertyContent extends LibertyBase {
}
}
// If sortmode is versions, links or backlinks sort using the ad-hoc function and reduce using old_offse and old_maxRecords
if ($old_sort_mode == 'versions_asc' && !empty( $ret['versions'] ) ) {
usort($ret, 'compare_versions');
}
@@ -1151,7 +1151,7 @@ class LibertyContent extends LibertyBase {
'backlinks_asc',
'backlinks_desc'
))) {
- $ret = array_slice($ret, $old_offset, $old_maxRecords);
+ $ret = array_slice($ret, $old_offset, $old_max_records);
}
$pListHash["data"] = $ret;
@@ -1118,7 +1118,7 @@ class LibertyContent extends LibertyBase {
}
}
- // If sortmode is versions, links or backlinks sort using the ad-hoc function and reduce using old_offse and old_maxRecords
+ // If sortmode is versions, links or backlinks sort using the ad-hoc function and reduce using old_offse and old_max_records
if ($old_sort_mode == 'versions_asc' && !empty( $ret['versions'] ) ) {
usort($ret, 'compare_versions');
diff --git a/plugins/data.category.php b/plugins/data.category.php
index 1c4325f..0d0bd29 100644
--- a/plugins/data.category.php
+++ b/plugins/data.category.php
@@ -1,6 +1,6 @@
<?php
/**
- * @version $Revision: 1.6 $
+ * @version $Revision: 1.7 $
* @package liberty
* @subpackage plugins_data
*/
@@ -18,7 +18,7 @@
// | by: StarRider <starrrider@users.sourceforge.net>
// | Reworked from: wikiplugin_category.php - see deprecated code below
// +----------------------------------------------------------------------+
-// $Id: data.category.php,v 1.6 2005/11/22 07:27:18 squareing Exp $
+// $Id: data.category.php,v 1.7 2006/02/06 00:09:01 squareing Exp $
/**
* definitions
@@ -172,10 +172,10 @@ function wikiplugin_category($data, $params) {
$listcat = array();
// title of categories
$title = '';
// TODO: allow 'find' and 'maxRecords'
$find = "";
$offset = 0;
- $maxRecords = 500;
+ $max_records = 500;
$count = 0;
$sort = (isset($sort)) ? $sort : "name_asc";
$types = (isset($types)) ? "+" . strtolower($types) : "*";
@@ -207,10 +207,10 @@ function wikiplugin_category($data, $params) {
$objectcat = array();
if ($sub) {
// get all items for category and sub category
- $objectcat = $categlib->list_category_objects_deep($id, $offset, $maxRecords, $sort, $find);
+ $objectcat = $categlib->list_category_objects_deep($id, $offset, $max_records, $sort, $find);
} else {
// get all items for category
- $objectcat = $categlib->list_category_objects($id, $offset, $maxRecords, $sort, $find);
+ $objectcat = $categlib->list_category_objects($id, $offset, $max_records, $sort, $find);
}
foreach ($objectcat["data"] as $obj) {
$type = $obj["type"];
@@ -172,10 +172,10 @@ function wikiplugin_category($data, $params) {
// title of categories
$title = '';
- // TODO: allow 'find' and 'maxRecords'
+ // TODO: allow 'find' and 'max_records'
$find = "";
$offset = 0;